﻿-- Author      : RisM
-- Create Date : 12/3/2009 2:43:45 AM

local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L = LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell", false)
local ResComm = LibStub:GetLibrary("LibResComm-1.0");

-------------------------------------------------------------------------------
-- REZ DETECTION
-------------------------------------------------------------------------------

-- A bridge between LibResComm-1.0 and SpeakinSpell
-- converts LibResComm events into OnSpeechEvent

-- the problem with Rez spells is that the blizz API fails to report targets
-- for players who released their spirits

-- LibResComm fixes that, and adds more


function SpeakinSpell:Rez_Init()
	-- setup for LibResComm notifications
	ResComm.RegisterCallback(self, "ResComm_ResStart");
	ResComm.RegisterCallback(self, "ResComm_ResEnd");
	ResComm.RegisterCallback(self, "ResComm_Ressed");
	ResComm.RegisterCallback(self, "ResComm_CanRes");
	ResComm.RegisterCallback(self, "ResComm_ResExpired");
end


function SpeakinSpell:ResComm_ResStart(event, resser, endTime, target)
	--Note: Messages comming from oRA2 will not have a reliable endTime.
	local destub = {
		type = "REZ",
		name = L["Start"],
		caster = resser,
		target = target,
		endtime = endTime, --TODONOW: investigate value/format
		pevent = event, --TODONOW: what is this?
	}
	self:OnSpeechEvent( destub )
end


function SpeakinSpell:ResComm_ResEnd(event, resser, target)
	--Fired when a resurrection cast ended. This can either mean it has failed or completed. Use ResComm_Ressed to check if someone actually ressed.
	local destub = {
		type = "REZ",
		name = L["End"],
		caster = resser,
		target = target,
		pevent = event, --TODONOW: what is this?
	}
	self:OnSpeechEvent( destub )
end


function SpeakinSpell:ResComm_Ressed(event, name)
	--Fired when someone actually sees the accept resurrection box.
	local destub = {
		type = "REZ",
		name = L["Received by target"],
		caster = resser,
		target = target,
		pevent = event, --TODONOW: what is this?
	}
	self:OnSpeechEvent( destub )
end


function SpeakinSpell:ResComm_CanRes(event, name)
	--Fired when someone can use a soulstone or ankh.
	local destub = {
		type = "REZ",
		name = L["Someone can self-res (SS, Ankh)"],
		caster = name,
		target = name,
		pevent = event, --TODONOW: what is this?
	}
	self:OnSpeechEvent( destub )
end


function SpeakinSpell:ResComm_ResExpired(event, name)
	--Fired when the accept resurrection box dissapears/is declined. 
	local destub = {
		type = "REZ",
		name = L["Expired"],
		caster = name, -- TODONOW: not necessarily?? who is the caster? do we know?
		target = name,
		pevent = event, --TODONOW: what is this?
	}
	self:OnSpeechEvent( destub )
end
